## 0.3.1 (2022-06-25)

ujson, pyfarmhash, toposort: check for missing definitions (#8153)

Co-authored-by: hauntsaninja <>

## 0.3.0 (2022-06-14)

[stubsabot] Bump pyfarmhash to 0.3.* (#8079)

Co-authored-by: hauntsaninja <>

## 0.2.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

